==> 1.0.0.tar.gz: lib/screens/QRDecrypt.dart <==

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:airpay_emar_package/model/Transaction.dart';
import 'package:airpay_emar_package/model/UserRequest.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:http/http.dart' as http;
import 'package:encrypt/encrypt.dart' as encrypt;
import 'package:airpay_emar_package/model/QrDecryptResponse.dart';


typedef void CallBack(CARDDETAILS response);
typedef void QRDecryptClosure(bool val, QrDecryptResponse response);


class QRDecrypt extends StatefulWidget {
  final QRDecryptClosure? qrDecryptClosure;
  final UserRequest user;

  QRDecrypt({Key? key, required this.user,this.qrDecryptClosure}) : super(key: key);
  @override
  _QRDecryptState createState() => new _QRDecryptState();
}

class _QRDecryptState extends State<QRDecrypt> {
  bool isShowProgress = true;
  var privateKey;
  var email;
  var mobileNo;
  var tokenData;
  var merchantId;


  @override
  void initState() {
    super.initState();
    var user = widget.user;
    makeApiCall(user.qrString);
  }

  showLoader(value) {
    setState(() {
      isShowProgress = value;
    });
  }


  // Function to make API call
  Future<void> makeApiCall(qrString) async {
    final url = 'https://emar.airpay.ninja/node/api/qrDecrypt'; // Replace with your API endpoint
    qrString = "08755e372cfe0dc6|472376a4f7d128f53d5162645fa7e0b28267a8aff60e7c3b1cafae478b2d9b06ba5f12a915e64bec3e67c6317f5c03a10fc2f7b1ebb05449cf3a4028a6a7426eed7e7fdf6357a038fe02033621f1ced3feb7757349d65a69f887bc8d4c078892fe09b7f7e2c31971c3293121e211e95a";
    print("qrString -->"+qrString);
    // Define your request headers
    Map<String, String> headers = {
      'AIRPAYKEY': 'AL0013AL1688469524',
      'PARTNERKEY': 'AF0064AF1688469603',
      'CHECKSUM': '4e043da782b8f0b7e5c9c1d5715ccf80a0313d5bc5e2050f051b4db1d5583bc1',
      'Content-Type': 'application/x-www-form-urlencoded'

    };

    // Define your request body
    Map<String, dynamic> requestBody = {
      'query': qrString,
    };


    // Send POST request to the API
    final response = await http.post(
      Uri.parse(url),
      headers: headers,
      body: requestBody,

    );

    if (response.statusCode == 200) {
      // Request successful, handle the response here
      print('API call successful');
      print(response.body);

      // Parse the response body as JSON
      Map<String, dynamic> parsedResponseStatus = jsonDecode(response.body);

      // Check if the 'status' key is present in the response
      if (parsedResponseStatus.containsKey('status')) {
        // Access the 'status' and 'message' properties in the parsed response
        int status = parsedResponseStatus['status'];
        String message = parsedResponseStatus['message'];

        print('Status: $status');
        print('Message: $message');


        widget.qrDecryptClosure!(true, QrDecryptResponse(status: status,message: message,data: null));
        return;
        // The rest of your code...
      } else  if (parsedResponseStatus.containsKey('query')) {
        // Parse the response body as JSON
        Map<String, dynamic> parsedResponse = jsonDecode(response.body);
        // Access the 'query' property in the parsed response
        String query = parsedResponse['query'];
        print('Query: $query');
        String decryptResponse = decryptStr(query);
        print('Decrypt Response : $decryptResponse');

        widget.qrDecryptClosure!(true, qrDecryptResponseFromJson(decryptResponse));
        return;
      }

    } else {
      // Request failed, handle the error here
      print('API call failed');
      print('Status Code: ${response.statusCode}');
      print('Response Body: ${response.body}');
    }
  }

  //Decryption Code for QR Decrypt API
  String decryptStr(String fullResponse){
    fullResponse.split("|");
    // String ivFromResponse = fullResponse.substring(0, 16);
    //String encryptedResponse = fullResponse.substring(16);
    String ivFromResponse = fullResponse.split("|")[0];
    String encryptedResponse = fullResponse.split("|")[1];
    print(ivFromResponse);
    print(encryptedResponse);

    final key = encrypt.Key.fromUtf8("5PbpCqeioHQ3MWj6dJVeluXD");
    final iv = encrypt.IV.fromUtf8(ivFromResponse);
    //final encrypter = encrypt.Encrypter(encrypt.AES(key,mode:encrypt.AESMode.cbc));
    final encrypter = encrypt.Encrypter(encrypt.AES(key, mode: encrypt.AESMode.cbc)); //, padding: 'PKCS7'


    final encrypted = encrypt.Encrypted.fromBase16(encryptedResponse);
    final decrypted = encrypter.decrypt(encrypted, iv: iv);

    print("Decrypted Response => $decrypted");
    return decrypted;
  }


  userCancel(String withMessage) {
    var trans = Transaction();
    trans.tRANSACTIONSTATUS = '500';
    trans.sTATUSMSG = withMessage;
  }

//   _showAlert(context, message) async {
//     await showDialog<String>(
//       context: context,
//       barrierDismissible: false,
//       builder: (BuildContext context) {
//         String title = "Airpay";
//         String message1 = message;
//         return Platform.isIOS
//             ? new CupertinoAlertDialog(
//           title: Text(title),
//           content: Text(message1),
//           actions: <Widget>[
//             new Container(
//               margin: EdgeInsets.all(8.0),
//               child: ElevatedButton(
// // padding: EdgeInsets.all(12.0),
//                 onPressed: () {
//                   Navigator.pop(context);
//                 },
// // color: Colors.blue[900],
//                 child: Text(
//                   'Okay',
//                   style: TextStyle(color: Colors.white, fontSize: 24.0),
//                 ),
//               ),
//             )
//           ],
//         )
//             : new AlertDialog(
//           title: Text(title),
//           content: Container(
//               height: 140.0,
//               width: 400.0,
//               child: ListView.builder(
//                   shrinkWrap: true,
//                   itemCount: 1,
//                   itemBuilder: (BuildContext context, int index) {
//                     return new Column(children: <Widget>[
//                       Text(message1),
//                     ]);
//                   })),
//           actions: <Widget>[
//             new Container(
//               margin: EdgeInsets.all(8.0),
//               child: ElevatedButton(
// // padding: EdgeInsets.all(2.0),
//                 onPressed: () {
//                   Navigator.pop(context);
//                 },
// // color: Colors.blue[900],
//                 child: Text(
//                   'Okay',
//                   style: TextStyle(color: Colors.white, fontSize: 24.0),
//                 ),
//               ),
//             )
//           ],
//         );
//       },
//     );
//   }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: Scaffold(
            appBar: AppBar(
              centerTitle: true,
              title: Image.asset(
                'assets/airpayLogo.png',
                height: 40,
                color: Colors.white,
                width: 200,
              ),
              leading: IconButton(
                icon: Icon(Icons.close),
                onPressed: () {
                  Navigator.pop(context);
                },
              ),
              backgroundColor: Colors.blue[900],
              actions: <Widget>[],
            ),
            body: isShowProgress ?
            Container(
                child: Center(
                    child: SpinKitCircle(
                      color: Colors.blue[900],
                      size: 50.0,
                    ))) : SizedBox()
        )
    );
  }
}

==> 1.0.2.tar.gz: lib/screens/QRDecrypt.dart <==

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:airpay_emar_package/model/Transaction.dart';
import 'package:airpay_emar_package/model/UserRequest.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:http/http.dart' as http;
import 'package:encrypt/encrypt.dart' as encrypt;
import 'package:airpay_emar_package/model/QrDecryptResponse.dart';
import 'package:crypto/crypto.dart';


typedef void CallBack(CARDDETAILS response);
typedef void QRDecryptClosure(bool val, QrDecryptResponse response);


class QRDecrypt extends StatefulWidget {
  final QRDecryptClosure? qrDecryptClosure;
  final UserRequest user;

  QRDecrypt({Key? key, required this.user,this.qrDecryptClosure}) : super(key: key);
  @override
  _QRDecryptState createState() => new _QRDecryptState();
}

class _QRDecryptState extends State<QRDecrypt> {
  bool isShowProgress = true;
  var privateKey;
  var email;
  var mobileNo;
  var tokenData;
  var merchantId;
  var secret_key ='b0B1c#dsaf45ADSF5645adf0215';

  @override
  void initState() {
    super.initState();
    var user = widget.user;
    makeApiCall(user.query);
  }

  showLoader(value) {
    setState(() {
      isShowProgress = value;
    });
  }


  // Function to make API call
  Future<void> makeApiCall(qrString) async {

    String stagingDataURL = "https://emar.airpay.ninja/node/api/qrDecrypt";
    String productionDataURL = "https://api.airpay.ae/node/api/qrDecrypt";
    String stagingAirpayKey = "AL0013AL1688469524";
    String stagingPartnerKey = "AF0064AF1688469603";
    String productionAirpayKey = "AL0015AL1693490184";
    String productionPartnerKey = "AF0038AF1693490253";

    var isGateWay = (widget.user.isStaging != null && widget.user.isStaging == true)
        ? stagingDataURL
        : productionDataURL;
    String url = isGateWay;

    var airpayKey = (widget.user.isStaging != null && widget.user.isStaging == true)
        ? stagingAirpayKey
        : productionAirpayKey;
    String airpay_Key = airpayKey;

    var partnerKey = (widget.user.isStaging != null && widget.user.isStaging == true)
        ? stagingPartnerKey
        : productionPartnerKey;
    String partner_Key = partnerKey;



    var checksum_header = sha256.convert(utf8.encode('${qrString.toString()}${secret_key.toString()}'));

    // Define your request headers
    Map<String, String> headers = {
      'AIRPAYKEY': airpay_Key,
      'PARTNERKEY': partner_Key,
      'CHECKSUM': checksum_header.toString(),
      'Content-Type': 'application/x-www-form-urlencoded'

    };

    // Define your request body
    Map<String, dynamic> requestBody = {
      'query': qrString,
    };


    // Send POST request to the API
    final response = await http.post(
      Uri.parse(url),
      headers: headers,
      body: requestBody,

    );

    if (response.statusCode == 200) {
      // Request successful, handle the response here

      // Parse the response body as JSON
      Map<String, dynamic> parsedResponseStatus = jsonDecode(response.body);

      // Check if the 'status' key is present in the response
      if (parsedResponseStatus.containsKey('status')) {
        // Access the 'status' and 'message' properties in the parsed response
        int status = parsedResponseStatus['status'];
        String message = parsedResponseStatus['message'];

        widget.qrDecryptClosure!(true, QrDecryptResponse(status: status,message: message,data: null));
        return;
        // The rest of your code...
      } else  if (parsedResponseStatus.containsKey('query')) {
        // Parse the response body as JSON
        Map<String, dynamic> parsedResponse = jsonDecode(response.body);
        // Access the 'query' property in the parsed response
        String query = parsedResponse['query'];
        String decryptResponse = decryptStr(query);

        widget.qrDecryptClosure!(true, qrDecryptResponseFromJson(decryptResponse));
        return;
      }

    } else {
      // Request failed, handle the error here
      print('API call failed');

    }
  }

  //Decryption Code for QR Decrypt API
  String decryptStr(String fullResponse){
    fullResponse.split("|");
    // String ivFromResponse = fullResponse.substring(0, 16);
    //String encryptedResponse = fullResponse.substring(16);
    String ivFromResponse = fullResponse.split("|")[0];
    String encryptedResponse = fullResponse.split("|")[1];

    final key = encrypt.Key.fromUtf8("5PbpCqeioHQ3MWj6dJVeluXD");
    final iv = encrypt.IV.fromUtf8(ivFromResponse);
    //final encrypter = encrypt.Encrypter(encrypt.AES(key,mode:encrypt.AESMode.cbc));
    final encrypter = encrypt.Encrypter(encrypt.AES(key, mode: encrypt.AESMode.cbc)); //, padding: 'PKCS7'


    final encrypted = encrypt.Encrypted.fromBase16(encryptedResponse);
    final decrypted = encrypter.decrypt(encrypted, iv: iv);

    return decrypted;
  }


  userCancel(String withMessage) {
    var trans = Transaction();
    trans.tRANSACTIONSTATUS = '500';
    trans.sTATUSMSG = withMessage;
  }


  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: Scaffold(
            appBar: AppBar(
              centerTitle: true,
              title: Image.asset(
                'assets/airpayLogo.png',
                height: 40,
                color: Colors.white,
                width: 200,
              ),
              leading: IconButton(
                icon: Icon(Icons.close),
                onPressed: () {
                  Navigator.pop(context);
                },
              ),
              backgroundColor: Colors.blue[900],
              actions: <Widget>[],
            ),
            body: isShowProgress ?
            Container(
                child: Center(
                    child: SpinKitCircle(
                      color: Colors.blue[900],
                      size: 50.0,
                    ))) : SizedBox()
        )
    );
  }
}
